@@ -21,7 +21,7 @@ DATABASES = {
 }
 
 ELASTICSEARCH_DSL['default'].update({
-    'hosts': "http://{{ ELASTICSEARCH_HOST }}:{{ ELASTICSEARCH_PORT }}/"
+    'hosts': "{{ ELASTICSEARCH_SCHEME }}://{{ ELASTICSEARCH_HOST }}:{{ ELASTICSEARCH_PORT }}/"
 })
 
 {% for name, index in DISCOVERY_INDEX_OVERRIDES.items() %}
